@@ -52,8 +52,8 @@ import types
 from contextlib import contextmanager
 from functools import wraps
 
+from vdsm.common.threadlocal import vars
 from vdsm.storage import exception as se
-from vdsm.storage.threadlocal import vars
 from vdsm.storage import outOfProcess as oop
 
 import uuid
